@@ -1,5 +1,5 @@
-require 'puppet/parser/ast/top_level_construct'
-require 'puppet/pops'
+require_relative '../../../puppet/parser/ast/top_level_construct'
+require_relative '../../../puppet/pops'
 
 # The AST::Bridge contains classes that bridges between the new Pops based model
 # and the 3.x AST. This is required to be able to reuse the Puppet::Resource::Type which is
@@ -57,10 +57,6 @@ class Puppet::Parser::AST::PopsBridge
   end
 
   class ExpressionSupportingReturn < Expression
-    def initialize args
-      super
-    end
-
     def evaluate(scope)
       return catch(:return) do
         return catch(:next) do
@@ -96,14 +92,8 @@ class Puppet::Parser::AST::PopsBridge
           instantiate_HostClassDefinition(d, modname)
         when Puppet::Pops::Model::ResourceTypeDefinition
           instantiate_ResourceTypeDefinition(d, modname)
-        when Puppet::Pops::Model::CapabilityMapping
-          instantiate_CapabilityMapping(d, modname)
         when Puppet::Pops::Model::NodeDefinition
           instantiate_NodeDefinition(d, modname)
-        when Puppet::Pops::Model::SiteDefinition
-            instantiate_SiteDefinition(d, modname)
-        when Puppet::Pops::Model::Application
-          instantiate_ApplicationDefinition(d, modname)
         else
           loaders = Puppet::Pops::Loaders.loaders
           loaders.instantiate_definition(d, loaders.find_loader(modname))
@@ -218,27 +208,6 @@ class Puppet::Parser::AST::PopsBridge
       instance
     end
 
-    def instantiate_CapabilityMapping(o, modname)
-      # Use an intermediate 'capability_mapping' type to pass this info to the compiler where the
-      # actual mapping takes place
-      Puppet::Resource::Type.new(:capability_mapping, "#{o.component} #{o.kind} #{o.capability}", { :arguments => {
-        'component'     => o.component,
-        'kind'          => o.kind,
-        'blueprint'     => {
-          :capability => o.capability,
-          :mappings   => o.mappings.reduce({}) do |memo, mapping|
-            memo[mapping.attribute_name] =
-              Expression.new(:value => mapping.value_expr)
-            memo
-          end
-      }}})
-    end
-
-    def instantiate_ApplicationDefinition(o, modname)
-      args = args_from_definition(o, modname)
-      Puppet::Resource::Type.new(:application, o.name, @context.merge(args))
-    end
-
     def instantiate_NodeDefinition(o, modname)
       args = { :module_name => modname }
 
@@ -257,17 +226,6 @@ class Puppet::Parser::AST::PopsBridge
       end
     end
 
-    def instantiate_SiteDefinition(o, modname)
-      args = { :module_name => modname }
-
-      unless is_nop?(o.body)
-        args[:code] = Expression.new(:value => o.body)
-      end
-
-      args = @ast_transformer.merge_location(args, o)
-      Puppet::Resource::Type.new(:site, 'site', @context.merge(args))
-    end
-
     def code()
       Expression.new(:value => @value)
     end
